Package: TreeAndLeaf
Type: Package
Title: Displaying binary trees with focus on dendrogram leaves
Version: 1.22.0
Description: The TreeAndLeaf package combines unrooted and force-directed graph algorithms in order to layout binary trees, aiming to represent multiple layers of information onto dendrogram leaves.
Author: Leonardo W. Kume, Luis E. A. Rizzardi, Milena A. Cardoso, Mauro A. A. Castro
Maintainer: Milena A. Cardoso <milenandreuzo@gmail.com>
Depends: R(>= 4.0)
Imports: RedeR(>= 1.40.4), igraph, ape
Suggests: knitr, rmarkdown, BiocStyle, RUnit, BiocGenerics, stringr,
        geneplast, ggtree, ggplot2, dplyr, dendextend, RColorBrewer
License: Artistic-2.0
Encoding: UTF-8
RoxygenNote: 7.1.1
VignetteBuilder: knitr
biocViews: Infrastructure, GraphAndNetwork, Software, Network,
        Visualization, DataRepresentation
NeedsCompilation: no
Packaged: 2025-10-30 07:00:45 UTC; biocbuild
git_url: https://git.bioconductor.org/packages/TreeAndLeaf
git_branch: RELEASE_3_22
git_last_commit: 1198a67
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
