# TreeAndLeaf 
An R package for displaying binary trees, aiming to represent multiple layers of information on dendrogram leaves.

## Installation
Install TreeAndLeaf from github:

```{r}
if (! requireNamespace("devtools", quietly = TRUE))
install.packages("devtools")
devtools::install_github("sysbiolab/TreeAndLeaf", force = TRUE, build_vignettes = TRUE)
```

For more info on how to use the package:

```{r}
vignette("TreeAndLeaf")
```
