#' Species tree from STRING-db v11
#'
#' A phylo object for the species tree available from the STRING-db v11.
#' 
#' @docType data
#' 
#' @name phylo_tree
#'
#' @usage data(phylo_tree)
#' 
#' @format An object of class \code{"phylo"}
#'
#' @keywords phylotree
#'
#' @references 
#' Szklarczyk D. et al. STRING v11: protein-protein association networks with 
#' increased coverage, supporting functional discovery in genome-wide 
#' experimental datasets. Nucleic Acids Res. 47:D607-613, 2019.

#' 
NULL