#' Species metadata from STRING-db v11
#'
#' Species metadata used in a phylo object.
#' 
#' @docType data
#' 
#' @name phylo_species
#'
#' @usage data(phylo_species)
#' 
#' @format An object of class \code{"data.frame"}
#'
#' @keywords datasets
#'
#' @references 
#' Szklarczyk D. et al. STRING v11: protein-protein association networks with 
#' increased coverage, supporting functional discovery in genome-wide 
#' experimental datasets. Nucleic Acids Res. 47:D607-613, 2019.
#' 
NULL